@@ -322,7 +322,7 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 	result = gtk_dialog_run(setup->selectDialog);
 	if (result == GTK_RESPONSE_ACCEPT) {
 		/*get the selected row and add the pertinant data to the entryList*/
-		destop_select_process(setup);
+		desktop_select_process(setup);
 	}
 	gtk_widget_destroy(GTK_WIDGET(setup->selectDialog));
 }
@@ -650,8 +650,10 @@ void edit_cmd(GtkButton *button, PersonalMenuSetup *setup)
 	GtkTreeSelection *select=gtk_tree_view_get_selection(setup->view);
 	GtkTreeModel *model=gtk_tree_view_get_model(setup->view);
 	GtkTreeIter iter;
-	gtk_tree_selection_get_selected(select,&model,&iter);
-	dialog_add_edit(iter,TRUE,setup);
+	if (gtk_tree_selection_get_selected(select,&model,&iter))
+	{
+		dialog_add_edit(iter,TRUE,setup);
+	}
 }
 
 void perform_deletion(PersonalMenuSetup *setup)
