@@ -325,12 +325,13 @@ static void menu_off(GtkMenu *menu, PersonalMenuNavigatorPlugin *plugin)
 }
 
 static void
-popup_menu (GtkWidget *button, PersonalMenuNavigatorPlugin *plugin)
+popup_menu(GtkWidget *button, GdkEventButton *event, PersonalMenuNavigatorPlugin *plugin)
 {
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
+	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
 	{
 		gtk_menu_popup (GTK_MENU (plugin->menu),NULL,NULL,(GtkMenuPositionFunc)menu_position,plugin,0,gtk_get_current_event_time());
 		plugin->popped=TRUE;
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(plugin->button),TRUE);
 	}
 }
 
@@ -359,6 +360,8 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 	gtk_widget_destroy(plugin->menu);
     plugin->menu = gtk_menu_new ();
 
+	g_object_set(plugin->menu,"background-color","red",NULL);
+
     keyFile=g_key_file_new();
     filename=g_strdup(HOME_DIR);
     filename=g_strconcat(filename,"/.personal_menu.rc",NULL);
@@ -633,7 +636,7 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   button = personal_menu_button_new (10);
   navigator_plugin->button=button;
   
-  g_signal_connect(G_OBJECT(button),"toggled",G_CALLBACK(popup_menu),navigator_plugin);
+  g_signal_connect(G_OBJECT(button),"button-release-event",G_CALLBACK(popup_menu),navigator_plugin);
   
   gtk_widget_set_size_request (button, 80, 80);
   gtk_widget_set_name (button, "hildon-navigator-button-one");
@@ -659,6 +662,8 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   navigator_plugin->updateTimeout=0;
   navigator_plugin->popped=FALSE;
   g_signal_connect(G_OBJECT(navigator_plugin->menu),"key-release-event",G_CALLBACK(key_release),navigator_plugin);
+  
+  gtk_widget_set_extension_events(button,GDK_EXTENSION_EVENTS_ALL);
 }
 
 static void
